---------------------------
-- lets simplify a bit..
---------------------------
local gf = Glance.Functions
local gv = Glance.Variables
local ga = Glance.Arrays
local gb = Glance.Buttons

---------------------------
-- create the button
---------------------------
gf.AddButton("Dungeons","RIGHT")
local btn = gb.Dungeons
btn.text              = "     "
btn.enabled           = true
btn.texture.normal    = "Interface\\AddOns\\Glance_Dungeons\\eye.tga"
btn.update            = true
btn.tooltip           = true
btn.menu              = true
btn.events            = {}

---------------------------
-- variables
---------------------------
gv.DungeonLevel = UnitLevel("player")

---------------------------
-- update
---------------------------
function gf.Dungeons.update(self, event, arg1)
	local btn = gb.Dungeons
	if btn.enabled and gv.loaded then -- loaded keeps it from launching when defined
		Glance.Debug("function","update","Dungeons")
		btn.button:SetWidth(16)
	end
end

---------------------------
-- tooltip
---------------------------
function gf.Dungeons.tooltip()
	Glance.Debug("function","tooltip","Dungeons")
	local tooltip = gf.Tooltip
	tooltip.Title("Dungeons", "GLD") 
	if gv.DungeonLevel == UnitLevel("player") then
		tooltip.Double("You are eligible for the following dungeons:","min (LFG min - LFG max)","WHT","GRN")
	else
		tooltip.Double("The following dungeons are available for level "..gv.DungeonLevel..":","min (LFG)","WHT","GRN")
	end
	tooltip.Space()
	gf.Dungeons.list(true)
	tooltip.Space()
	tooltip.Line("Raids", "GLD")
	if gv.DungeonLevel == UnitLevel("player") then
		tooltip.Double("You are eligible for the following raids:","min (LFG min - LFG max)","WHT","GRN")
	else
		tooltip.Double("The following raids are available for level "..gv.DungeonLevel..":","min (LFG)","WHT","GRN")
	end
	tooltip.Space()
	gf.Dungeons.list(false)
	tooltip.Space()
	tooltip.Line("(Right-Click to change character level.)","WHT")
end


---------------------------
-- menu
---------------------------
function gf.Dungeons.menu(level,UIDROPDOWNMENU_MENU_VALUE)
	Glance.Debug("function","menu","Dungeons")
	local HEX = ga.colors.HEX
	level = level or 1
	if (level == 1) then
		gf.setInfo(nil,true,false,true,nil,HEX.white.."Dungeons Options","spacer",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Levels 1-9","9",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Levels 10-19","19",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Levels 20-29","29",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Levels 30-39","39",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Levels 40-49","49",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Levels 50-59","59",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Levels 60-69","69",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Levels 70-79","79",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Levels 80-85","85",level,nil)
		gf.setInfo(nil,nil,true,true,nil,HEX.gold.."Levels 86-90","90",level,nil)
	end
	if (level == 2) then
		for i=tonumber(UIDROPDOWNMENU_MENU_VALUE)-10,tonumber(UIDROPDOWNMENU_MENU_VALUE) do
			local checked, func
			checked = (gv.DungeonLevel == i)
			func = function() gv.DungeonLevel = i; end;
			gf.setInfo(nil,false,false,false,checked,i,i,level,func)
		end
	end
end

---------------------------
-- list dungeons and raids
---------------------------
function gf.Dungeons.list(instance)
	local tooltip = gf.Tooltip
	local itemLevel = math.floor(GetAverageItemLevel())
	for i=1,#Glance.Data.Dungeons do
		local dmin, lfgmin, lfgmax, dilvl, hmin, hlfgmin, hlfgmax, hilvl, dtype, name, location = unpack(Glance.Data.Dungeons[i])
		if (instance and dtype == 5) or (not instance and dtype > 5) then
			local mode, lvls, eligible = "","",false
			--if level between heroic min and heroic lfg max
			if gv.DungeonLevel >= dmin and gv.DungeonLevel <= lfgmax then
				mode = "normal"
				lvls = dmin.." ("..lfgmin.."-"..lfgmax..")"
				if itemLevel >= dilvl then eligible = true end
			end
			if (gv.DungeonLevel >= hmin and gv.DungeonLevel <= hlfgmax) and hmin ~= 0 then
				mode = mode.."/"..ga.colors.HEX.purple.."heroic"
				lvls = lvls..ga.colors.HEX.purple.." "..hmin.." ("..hlfgmin.."-"..hlfgmax..")"
			end
			if eligible then
				tooltip.Double(ga.colors.HEX.yellow..location..": |r"..name.." ("..mode.."|r)",lvls,"WHT","GRN")
			end
		end
	end
end

---------------------------
-- data
---------------------------
Glance.Data.Dungeons = {
  --min","lfgm","lfgmax","ilvl","hmin","hlfgm","hlfgmax","hilvl","man","name","loc" ,
	{ 10,15,21,0,85,85,85,329,5,"The Deadmines","Westfall" },
	{ 10,15,21,0,0,0,0,0,5,"Ragefire Chasm","Orgrimmar" },
	{ 10,15,25,0,0,0,0,0,5,"Wailing Caverns","Northern Barrens" },
	{ 11,16,26,0,85,85,85,329,5,"Shadowfang Keep","Silverpine Forest" },
	{ 15,20,30,0,0,0,0,0,5,"Stormwind Stockade","Stormwind City" },
	{ 15,20,30,0,0,0,0,0,5,"Blackfathom Deeps","Ashenvale" },
	{ 19,24,34,0,0,0,0,0,5,"Gnomeregan","Dun Morogh" },
	{ 21,32,42,0,0,0,0,0,5,"The Scarlet Halls","Tirisfal Glades" },
	{ 21,35,45,0,0,0,0,0,5,"The Scarlet Monastery","Tirisfal Glades" },
	{ 25,30,40,0,0,0,0,0,5,"Razorfen Kraul","Southern Barrens" },
	{ 25,30,40,0,0,0,0,0,5,"Maraudon - Purple Crystals","Desolace" },
	{ 25,32,42,0,0,0,0,0,5,"Maraudon - Orange Crystals","Desolace" },
	{ 25,34,44,0,0,0,0,0,5,"Maraudon - Pristine Waters","Desolace" },
	{ 30,35,45,0,0,0,0,0,5,"Uldaman","Badlands" },
	{ 31,36,46,0,0,0,0,0,5,"Dire Maul - Warpwood Quater (East)","Feralas" },
	{ 33,38,48,0,90,90,90,463,5,"Scholomance","Western Plaguelands" },
	{ 34,39,49,0,0,0,0,0,5,"Dire Maul - Capital Gardens (West)","Feralas" },
	{ 35,40,50,0,0,0,0,0,5,"Razorfen Downs","Thousand Needles" },
	{ 37,42,52,0,0,0,0,0,5,"Dire Maul - Gordok Commons (North)","Feralas" },
	{ 37,42,52,0,0,0,0,0,5,"Stratholme - Main Gate","Eastern Plaguelands" },
	{ 37,46,56,0,0,0,0,0,5,"Stratholme - Service Entrance","Eastern Plaguelands" },
	{ 39,44,54,0,0,0,0,0,5,"Zul'Farrak","Tanaris" },
	{ 42,47,57,0,0,0,0,0,5,"Blackrock Depths - Detention Block","Blackrock Mountain" },
	{ 42,51,61,0,0,0,0,0,5,"Blackrock Depths - Upper City","Blackrock Mountain" },
	{ 45,50,60,0,0,0,0,0,5,"Temple of Atal'Hakkar","Swamp of Sorrows" },
	{ 48,55,65,0,0,0,0,0,5,"Lower Blackrock Spire","Blackrock Mountain" },
	{ 48,55,65,0,0,0,0,0,5,"Upper Blackrock Spire","Blackrock Mountain" },
	{ 50,60,65,0,0,0,0,0,40,"Molten Core","Blackrock Mountain" },
	{ 50,60,65,0,0,0,0,0,10,"Ruins of Ahn'Qiraj","Ahn'Qiraj" },
	{ 55,60,65,0,0,0,0,0,40,"Blackwing Lair","Blackrock Mountain" },
	{ 50,60,65,0,0,0,0,0,40,"Temple of Ahn'Qiraj","Ahn'Qiraj" },
	{ 57,59,67,0,57,70,72,0,5,"Hellfire Ramparts","Hellfire Peninsula" },
	{ 58,61,68,0,58,70,72,0,5,"Blood Furnace","Hellfire Peninsula" },
	{ 59,62,69,0,59,70,72,0,5,"Slave Pens","Zangarmarsh" },
	{ 60,63,70,0,70,70,72,0,5,"Underbog","Zangarmarsh" },
	{ 61,64,71,0,70,70,72,0,5,"Mana-Tombs","Terokkar Forest" },
	{ 62,65,72,0,70,70,72,0,5,"Auchenai Crypts","Terokkar Forest" },
	{ 66,66,73,0,70,70,72,0,5,"Escape from Durnholde","Tanaris" },
	{ 63,67,73,0,70,70,72,0,5,"Sethekk Halls","Terokkar Forest" },
	{ 65,67,75,0,70,70,72,0,5,"The Steamvault","Zangarmarsh" },
	{ 65,67,75,0,70,70,72,0,5,"Shattered Halls","Hellfire Peninsula" },
	{ 65,67,75,0,70,70,72,0,5,"Shadow Labyrinth","Terokkar Forest" },
	{ 67,67,75,0,70,70,72,0,5,"The Mechanar","Netherstorm" },
	{ 67,67,75,0,70,70,72,0,5,"Botanica","Netherstorm" },
	{ 65,68,75,0,70,70,72,0,5,"Arcatraz","Netherstorm" },
	{ 66,68,75,0,70,70,72,0,5,"Black Morass","Tanaris" },
	{ 65,68,75,0,70,70,72,0,5,"Magisters' Terrace","Isle of Quel'Danas" },
	{ 68,70,75,0,70,70,72,0,10,"Karazhan","Deadwind Pass" },
	{ 65,70,75,0,70,70,72,0,25,"Gruul's Lair","Blade's Edge Mountains" },
	{ 65,70,75,0,70,70,72,0,25,"Magtheridon's Lair","Hellfire Peninsula" },
	{ 70,70,75,0,70,70,72,0,10,"Zul'Aman","Ghostlands" },
	{ 70,70,75,0,70,70,72,0,25,"Serpentshrine Cavern","Zangarmarsh" },
	{ 70,70,75,0,70,70,72,0,25,"Tempest Keep: The Eye","Netherstorm" },
	{ 70,70,75,0,70,70,72,0,25,"Hyjal Summit","Tanaris" },
	{ 70,70,75,0,70,70,72,0,25,"Black Temple","Shadowmoon Valley" },
	{ 70,70,75,0,70,70,72,0,25,"Sunwell Plateau","Isle of Quel'Danas" },
	{ 67,69,72,0,80,80,81,180,5,"Utgarde Keep","Howling Fjord" },
	{ 68,71,73,0,80,80,81,180,5,"The Nexus","Borean Tundra" },
	{ 69,72,74,0,80,80,81,180,5,"Azjol-Nerub","Dragonblight" },
	{ 70,73,75,0,80,80,81,180,5,"Ahn'kahet: The Old Kingdom","Dragonblight" },
	{ 71,74,76,0,80,80,81,180,5,"Drak'Tharon Keep","Zul'Drak" },
	{ 72,75,77,0,80,80,81,180,5,"The Violet Hold","Dalaran" },
	{ 73,76,78,0,80,80,81,180,5,"Gundrak","Zul'Drak" },
	{ 74,77,79,0,80,80,81,180,5,"Halls of Stone","Storm Peaks" },
	{ 75,79,81,0,80,80,81,180,5,"Oculus","Borean Tundra" },
	{ 75,79,81,0,80,80,81,180,5,"Halls of Lightning","Storm Peaks" },
	{ 75,79,81,0,80,80,81,180,5,"Utgarde Pinnacle","Howling Fjord" },
	{ 75,79,81,0,80,80,81,180,5,"Culling of Stratholme","Tanaris" },
	{ 75,79,81,160,80,80,81,180,5,"Trial of the Champion","Icecrown" },
	{ 75,79,81,160,80,80,81,180,5,"Forge of Souls","Icecrown" },
	{ 75,79,81,180,80,80,81,200,5,"Pit of Saron","Icecrown" },
	{ 75,79,81,180,80,80,81,219,5,"Halls of Reflection","Icecrown" },
	{ 80,80,81,0,80,80,81,0,25,"Naxxramas","Dragonblight" },
	{ 80,80,81,0,80,80,81,0,25,"Obsidian Sanctum","Dragonblight" },
	{ 80,80,81,0,80,80,81,0,25,"Vault of Archavon","Wintergrasp" },
	{ 80,80,81,0,80,80,81,0,25,"Eye of Eternity","Borean Tundra" },
	{ 80,80,81,0,80,80,81,0,25,"Ulduar","Storm Peaks" },
	{ 80,80,81,0,80,80,81,0,25,"Trial of the Crusader","Icecrown" },
	{ 80,80,81,0,80,80,81,0,25,"Onyxia's Lair","Dustwallow Marsh" },
	{ 80,80,81,0,80,80,81,0,25,"Ruby Sanctum","Dragonblight" },
	{ 80,80,81,0,80,80,81,0,25,"Icecrown Citadel","Icecrown" },
	{ 80,80,83,226,85,85,85,329,5,"Throne of the Tides","Abyssal Maw" },
	{ 80,80,83,226,85,85,85,329,5,"Blackrock Caverns","Blackrock Mountain" },
	{ 81,82,84,272,85,85,85,329,5,"The Stonecore","Deepholm" },
	{ 81,82,84,272,85,85,85,329,5,"The Vortex Pinnacle","Uldum" },
	{ 84,85,85,305,85,85,85,329,5,"Lost City of Tol'vir","Uldum" },
	{ 84,85,85,305,85,85,85,329,5,"Grim Batol","Twilight Highlands" },
	{ 84,85,85,305,85,85,85,329,5,"Halls of Origination","Uldum" },
	{ 85,85,85,329,85,85,85,329,25,"Baradin Hold","Tol Barad" },
	{ 85,85,85,342,85,85,85,342,25,"The Bastion of Twilight","Twilight Highlands" },
	{ 85,85,85,342,85,85,85,342,25,"Throne of the Four Winds","Uldum" },
	{ 85,85,85,342,85,85,85,342,25,"Blackwing Descent","Blackrock Mountain" },
	{ 85,85,85,0,85,85,85,346,5,"Zul'Aman","Ghostlands" },
	{ 85,85,85,0,85,85,85,346,5,"Zul'Gurub","Stranglethorn" },
	{ 85,85,85,359,85,85,85,359,25,"Firelands","Mount Hyjal" },
	{ 85,85,85,0,85,85,85,353,5,"End Time","Tanaris" },
	{ 85,85,85,0,85,85,85,353,5,"Well of Eternity","Tanaris" },
	{ 85,85,85,0,85,85,85,353,5,"Hour of Twilight","Tanaris" },
	{ 85,85,85,365,85,85,85,372,25,"Dragon Soul","Tanaris" },
  --min","lfgm","lfgmax","ilvl","hmin","hlfgm","hlfgmax","hilvl","man","name","loc" ,
	{ 85,85,87,358,90,90,90,440,5,"Temple of the Jade Serpent","Jade Forest" },
	{ 85,85,87,358,90,90,90,440,5,"Stormstout Brewery","Valley of the Four Winds" },
	{ 87,87,89,393,90,90,90,440,5,"Shado-Pan Monastery","Kun-Lai Summit" },
	{ 87,87,89,393,90,90,90,440,5,"Mogu'shan Palace","Vale of Eternal Blossoms" },
	{ 90,90,90,440,90,90,90,440,5,"Gate of the Setting Sun","Great Pandarian Wall" },
	{ 90,90,90,440,90,90,90,440,5,"Siege of Niuzao Temple","Townlong Steppes" },	
	{ 90,90,90,460,90,90,90,460,25,"Mogu'shan Vaults","Kun-Lai Summit" },
	{ 90,90,90,470,90,90,90,470,25,"Terrace of Endless Spring","The Veiled Stair" },
	{ 90,90,90,470,90,90,90,470,25,"Heart of Fear","Dread Wastes" },
	{ 90,90,90,480,90,90,90,480,25,"Throne of Thunder","Isle of Thunder" },
	{ 90,90,90,480,90,90,90,480,25,"Siege of Orgrimmar","Vale of Eternal Blossoms" },
}

---------------------------
-- load on demand
---------------------------
if gv.loaded then
	gf.Enable("Dungeons")
end